pub struct BuilderTestExpected {
pub success: bool,
pub typed_root: Option<TypedRootData>,
pub errors: Vec<String>,
}Expand description
Expected builder test results for comparison.
This struct represents the expected output of a builder test, including success status, typed root structure, and any expected errors.
Fields
success: booltyped_root: Option<TypedRootData>errors: Vec<String>Trait Implementations
Sourceimpl Debug for BuilderTestExpected
impl Debug for BuilderTestExpected
Sourceimpl<'de> Deserialize<'de> for BuilderTestExpected
impl<'de> Deserialize<'de> for BuilderTestExpected
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BuilderTestExpected
impl PartialEq for BuilderTestExpected
Sourceimpl Serialize for BuilderTestExpected
impl Serialize for BuilderTestExpected
impl StructuralPartialEq for BuilderTestExpected