pub struct TypedRootData {
pub type_name: String,
pub content: Value,
}Expand description
Typed root data structure for builder testing.
Represents the typed root structure with its type name and serialized content used for testing builder output. Since TypedRoot can be any type, we serialize it as a generic structure for comparison.
Fields
type_name: Stringcontent: ValueTrait Implementations
Sourceimpl Debug for TypedRootData
impl Debug for TypedRootData
Sourceimpl<'de> Deserialize<'de> for TypedRootData
impl<'de> Deserialize<'de> for TypedRootData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TypedRootData
impl PartialEq for TypedRootData
Sourceimpl Serialize for TypedRootData
impl Serialize for TypedRootData
impl StructuralPartialEq for TypedRootData