pub struct AstNodeData {
pub kind: String,
pub children: Vec<AstNodeData>,
pub text_length: usize,
pub is_leaf: bool,
}Expand description
AST node data structure for parser testing.
Represents a node in the abstract kind tree with its kind, children, text length, and leaf status used for testing parser output.
Fields
kind: Stringchildren: Vec<AstNodeData>text_length: usizeis_leaf: boolTrait Implementations
Sourceimpl Debug for AstNodeData
impl Debug for AstNodeData
Sourceimpl<'de> Deserialize<'de> for AstNodeData
impl<'de> Deserialize<'de> for AstNodeData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AstNodeData
impl PartialEq for AstNodeData
Sourceimpl Serialize for AstNodeData
impl Serialize for AstNodeData
impl StructuralPartialEq for AstNodeData